#!/bin/sh

# Name:		giblib
# Summary:	Utility library for scrot
# Version: 	1.2.4
# Copyright: 	Free
# Source: 	http://www.linuxbrit.co.uk/downloads/giblib-1.2.4.tar.gz
# Url: 		http://www.linuxbrit.co.uk
# Packager:	Mauricio <zariweb@gmail.com>


NAME=giblib
VERSION=${VERSION:-1.2.4}
RELEASE=${RELEASE:-48.1}
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}

CWD="`pwd`"
TMP=${TMP:-/tmp}
ROOT=${ROOT:-$TMP/package-$NAME}

# Check if running with root priviledges
if [ "`id -u`" != "0" ]; then
	echo "Need to be root to build this package"
	exit 1
fi

cd $TMP
rm -rf $NAME-$VERSION
tar xf $CWD/$NAME-$VERSION.tar.gz || exit $?

cd $NAME-$VERSION

chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var \
	--mandir=/usr/man || exit $?

make || exit $?

rm -rf $ROOT
mkdir -p $ROOT
make install DESTDIR=$ROOT

# Copy docs into the package
mkdir -p $ROOT/usr/doc/$NAME-$VERSION
cp -a AUTHORS README ChangeLog TODO \
	$ROOT/usr/doc/$NAME-$VERSION 2> /dev/null

# Remove redundant docs
rm -rf $ROOT/usr/doc/$NAME 2>/dev/null

# Strip debug info from binaries
(
  cd $ROOT ;
  find . -print0 | xargs -0 file | grep "executable" | grep ELF | cut -d : -f 1 | xargs strip --strip-unneeded ;
  find . -print0 | xargs -0 file | grep "shared object" | grep ELF | cut -d : -f 1 | xargs strip --strip-unneeded ;
  find . -print0 | xargs -0 file | grep "ar archive" | cut -d : -f 1 | xargs strip --strip-unneeded ; 
)

# Compress man pages
gzip -9 $ROOT/usr/man/man?/*

# Write out the slack-desc file
mkdir -p $ROOT/install
cat << EOF > $ROOT/install/slack-desc
giblib: Utility library and imlib2 wrapper
giblib:
giblib: giblib is a small utility library and imlib2 wrapper used
giblib: by scrot and other software.
giblib:
giblib:
giblib:
giblib:
giblib:
giblib:
giblib:
EOF

# Copy this build script into the package
mkdir -p $ROOT/usr/src/$NAME-$VERSION
cp $CWD/build-$NAME.sh $ROOT/usr/src/$NAME-$VERSION/

# Finally build the package, checksum and dependencies files
cd $ROOT 
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$RELEASE.tgz

cd $CWD
echo "Generating md5 checksum"
md5sum $NAME-$VERSION-$ARCH-$RELEASE.tgz > $NAME-$VERSION-$ARCH-$RELEASE.md5

echo "Generating dependencies file"
requiredbuilder -z $NAME-$VERSION-$ARCH-$RELEASE.tgz > $NAME-$VERSION-$ARCH-$RELEASE.dep

# Clean up all the mess
if [ "$1" == "cleanup" ]; then
  rm -rf $TMP/$NAME-$VERSION
  rm -rf $ROOT
fi

